import "Turbine.UI";
import "Turbine.UI.Lotro";
-----------------------------------
import "Gillothrin.Items.BaseFunc";
import "Gillothrin.Items.ItemStat";


ItemsWindow = class(Turbine.UI.Lotro.Window());
function ItemsWindow:Constructor(optionsObj,playerWallet)
	Turbine.UI.Lotro.Window.Constructor(self);
	self.maxScreenWidth = Turbine.UI.Display:GetWidth();
	
	self.playerWallet = playerWallet;
	self.defaultWidth = 460;
	self.defaultHeight = 80;
	self.itemStats = {};
	self.optionsObj = optionsObj;
	
	self:SetText("~Items~");
	self:SetResizable(false);
	self:SetMinimumHeight(self.defaultHeight);
	
	self:SetSize(self.defaultWidth, self.defaultHeight);
	
	if(optionsObj.mainLeft ~= nil) and (optionsObj.mainTop ~= nil) then	
		self:SetPosition(optionsObj.mainLeft,optionsObj.mainTop);
	else
		self:SetDefaultPosition();
	end

	-- TODO For some reason, this doesn't work... Doesn't get triggered. Fixed when closing the plugin
	self:SetWantsUpdates(true);
	local this = self;
	self.PositionChangedEventHandler = function(sender, args)
		debug("PositionChangedEventHandler");
		if (this.optionsObj.mainLeft ~= this:GetLeft()) or (this.optionsObj.mainTop ~= this:GetTop()) then
			this.optionsObj.mainLeft = this:GetLeft();
			this.optionsObj.mainTop = this:GetTop();
		end
	end
	AddCallback(self,"PositionChanged",self.PositionChangedEventHandler);
end

function ItemsWindow:Cleanup()
	local v = self.itemStats;
	for i=1,#v do
		v[i]:Cleanup();
	end
	self:GetControls():Clear();
	self.itemStats = {};
end

function ItemsWindow:Unload()
	self:Cleanup();
	RemoveCallback(self,"PositionChanged",self.PositionChangedEventHandler);
end

function ItemsWindow:RepaintItemInfo()
	self:Cleanup();
	self.playerWallet:LoadWallet();
	local xCoord = 15; -- 15 padding
	local calcWindowSize = 27;
	local phialIdx = 0;
	local maxWidth = 0;
	local foundItems = self.playerWallet:GetFoundItems();
	local pkeys = {};
	for k,v in pairs(foundItems) do 
		if(not self.optionsObj.notSelectedItems[k]) then
			maxWidth = math.max(string.len(v:GetQuantity()),maxWidth);
			table.insert(pkeys,k);
		end
	end
		
	table.sort(pkeys, function(a,b) return tostring(a) < tostring(b) end);
	 -- some magic stuff since the window have all those decorations
	local row = 0;
	local shouldWrap = false;
	local textWidth = -1;
	local itemStatElementSize = (maxWidth*7+4+15);
		
	if(itemStatElementSize*#pkeys > self.maxScreenWidth) then
		textWidth = maxWidth;
		shouldWrap = true;
	end
	
	for _,k in ipairs(pkeys) do
		local p = ItemStat(foundItems[k],k,textWidth);
		p:SetParent(self);
		if(shouldWrap)then
			if(xCoord + itemStatElementSize > self.maxScreenWidth-27) then
				row = row + 1;
				xCoord = 15;
			end
		end
		p:SetPosition(xCoord, (math.floor(self.defaultHeight/2)-3)+(18*row));
		calcWindowSize = calcWindowSize + p:GetWidth();
		xCoord = xCoord + p:GetWidth();
		self.itemStats[phialIdx] = p;
		phialIdx = phialIdx + 1;
	end
	
	if(shouldWrap)then
		calcWindowSize = self.maxScreenWidth-27;
	end
	self:SetSize(calcWindowSize,self.defaultHeight+(18*row));
end

function ItemsWindow:LoadWindow()
	self:RepaintItemInfo();
	self:SetVisible(true);
end

function ItemsWindow:ResetWindow()
	self:SetDefaultPosition();
	self:LoadWindow();
end

function ItemsWindow:SetDefaultPosition()
	self:SetPosition((self.maxScreenWidth/2-(self:GetWidth()/2)),(Turbine.UI.Display:GetHeight()/2));
end